import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bounceable/flutter_bounceable.dart';

import '../../common/values/sizes.dart';
import '../custom/custom_icon.dart';
import '../dialog/custom_will_pop_back.dart';
import '../text/custom_text_medium_bold_field.dart';

class CustomAppBarArrowTransparent extends StatelessWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isWarning;
  final Color? textColor;
  final Function()? cartCallBack;

  const CustomAppBarArrowTransparent(
      {required this.title,
      this.tabBarMenu,
      this.textColor,
      this.isWarning = false,
      this.tabBarMenuRight,
      this.cartCallBack});

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.transparent,
      child: Column(
        children: [
          SafeArea(
            maintainBottomViewPadding: false,
            bottom: false,
            child: Padding(
              padding: EdgeInsets.only(left: 10),
              child: SizedBox(
                height: Sizes.HEIGHT_52,
                width: Sizes.width(context),
                child: GestureDetector(
                  onTap: () => CustomWillPopBack.Pop(context, isWarning),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Flexible(
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Flexible(
                              child: Row(
                                children: [
                                  Container(
                                      width: Sizes.WIDTH_32,
                                      height: Sizes.HEIGHT_32,
                                      decoration: BoxDecoration(
                                          color: Colors.grey.withOpacity(0.4),
                                          borderRadius:
                                              BorderRadius.circular(100)),
                                      child: CustomIcon(
                                        icon:
                                            Icons.keyboard_arrow_left_outlined,
                                        color: textColor ?? Colors.black,
                                        size: 36,
                                      )),
                                  Expanded(
                                    child: CustomTextMediumBoldField(
                                      label: title + "  ",
                                      color: textColor,
                                    ),
                                  ),
                                ],
                              ),
                            ),
                            if (cartCallBack != null) ...[
                              Expanded(
                                child: Container(
                                  width: Sizes.WIDTH_32,
                                  height: Sizes.HEIGHT_32,
                                  decoration: BoxDecoration(
                                      color: Colors.grey.withOpacity(0.4),
                                      borderRadius: BorderRadius.circular(100)),
                                  child: Bounceable(
                                      onTap: () => cartCallBack!(),
                                      child: Icon(
                                        CupertinoIcons.cart_fill,
                                        color: Colors.black87,
                                      )),
                                ),
                              )
                            ]
                          ],
                        ),
                      ),
                      Flexible(
                        child: tabBarMenuRight ?? Container(),
                      )
                    ],
                  ),
                ),
              ),
            ),
          ),
          tabBarMenu ?? Container(),
        ],
      ),
    );
  }
}
